@@ -574,9 +574,9 @@ int main() { return f(42); }
         self.assertNotIn('(no debugging symbols found)', pr['Stacktrace'])
         self.assertNotIn('Core was generated by', pr['Stacktrace'])
         self.assertNotRegex(pr['Stacktrace'], r'(?s)(^|.*\n)#0  [^\n]+\n#0  ')
-        self.assertIn('#0  0x', pr['Stacktrace'])
+        self.assertIn('#0  ', pr['Stacktrace'])
         self.assertIn('#1  0x', pr['Stacktrace'])
-        self.assertIn('#0  0x', pr['ThreadStacktrace'])
+        self.assertIn('#0  ', pr['ThreadStacktrace'])
         self.assertIn('#1  0x', pr['ThreadStacktrace'])
         self.assertIn('Thread 1 (', pr['ThreadStacktrace'])
         self.assertLessEqual(len(pr['StacktraceTop'].splitlines()), 5)
@@ -2246,5 +2246,6 @@ No symbol table info available.
         del r['Date']
         self.assertEqual(r.get_timestamp(), None)
 
+
 if __name__ == '__main__':
     unittest.main()
